import time
import serial

# send SCPI command
def scpi(msg):
  global ser
  ser.write(msg+"\r\n")
  return

# single measurement
def measure():

  # configure Agilent for the measurement
  scpi("SYST:REM")
  scpi("*RST")
  time.sleep(1)  
  
  # channels 102,103 - junction Cu-Ko
  scpi("CONF:TEMP TC,T,(@102,103)")
  scpi("UNIT:TEMP K,(@102,103)")
  # channel 101 - 4w RTD on Pt, paired to 111
  scpi("CONF:TEMP FRTD,85,(@101)")
  scpi("UNIT:TEMP C,(@101)")
  # use 101 as reference for 102,103
  scpi("SENS:TEMP:TRAN:TC:RJUN:TYPE EXT,(@102,103)")
  # channels 104,105 - DC voltage
  scpi("CONF:VOLT:DC (@104,105)")
  # channel 112 - resistance (compensated) 
  scpi("CONF:RES (@112)")
  scpi("SENS:RES:OCOM ON,(@112)")
  




  # what to scan
  scpi("ROUTE:SCAN (@101,102,103,104,105,112)")
  
  # initialize scan
  scpi("INIT")

  print   "Initialization of channels O.K."

  time.sleep(2)   # it has to wait here for >= 2 seconds, otherwise gives error 222


  
  # read data
  print   "Reading data"
  scpi("DATA:REMOVE? 6")    #reads the 6 readings and erase them from memory
  meastr=ser.readline()

  print   "Scan performed"
  
  # end remote control
  scpi("ROUT:MON:STAT ON")
  scpi("SYST:LOC")

  return meastr


#- main program -------------------------------------------------

# user input

print 
Nmeas=input("total number of scans     : ")
dtime=input("delay between scans [min] : ")
fname=raw_input("output file               : ")
print 

dat = open(fname,'w')
print >> dat, "# index   time[min]   Tref[C]     T1[K]        T2[K]           U14[V]          U23[V]            R[Ohm]"
dat.close


# Agilent 34970A communication settings

ser=serial.Serial(0) # COM1
ser.baudrate=4800
ser.parity = serial.PARITY_NONE
ser.bytesize = serial.EIGHTBITS
ser.stopbits = 1
ser.xonxoff = 0


# experiment

time1=time.time()
for i in range(Nmeas):

  # perform scan
  mstr=measure()
  Tref,T1,T2,U14,U23,R=map(float,mstr[:-2:].split(','))

  # show time 
  time2=time.time()
  mark=time.strftime("%a, %d %b %Y %H:%M:%S",time.localtime(time2))
  print mark

  # show measured temperatures
  print 'scan %d  time=%.2fmin  T1=%7.3fK  T2=%7.3fK  Tavg=%7.3fK  dT=%6.3fK' \
        %(i+1,(time2-time1)/60,T1,T2,(T1+T2)/2,T2-T1)
  print
 
  # append results to the file
  dat = open(fname,'a')
  results='%5d %10.2f   %12.6f %12.6f %12.6f   %15.9f %15.9f   %12.6f' \
          % (i+1,(time2-time1)/60,Tref,T1,T2,U14,U23,R)
  print >> dat, results+"     \""+mark+"\""
  dat.close()

  # wait for next scan
  if i<(Nmeas-1):
    time.sleep(dtime*60-2.83)  


ser.close()
raw_input('press Enter...')
